.. _api_reference_toplevel:

API Reference
=============

Version
-------

.. py:data:: git.__version__

   Current GitPython version.

Objects.Base
------------

.. automodule:: git.objects.base
   :members:
   :undoc-members:
   :special-members:
 
Objects.Blob
------------

.. automodule:: git.objects.blob
   :members:
   :undoc-members:
   :special-members:
   
Objects.Commit
--------------

.. automodule:: git.objects.commit
   :members:
   :undoc-members:
   :special-members:
   
Objects.Tag
-----------

.. automodule:: git.objects.tag
   :members:
   :undoc-members:
   :special-members:

Objects.Tree
------------

.. automodule:: git.objects.tree
   :members:
   :undoc-members:
   :special-members:

Objects.Functions
-----------------

.. automodule:: git.objects.fun
   :members:
   :undoc-members:
   :special-members:

Objects.Submodule.base
----------------------

.. automodule:: git.objects.submodule.base
   :members:
   :undoc-members:
   :special-members:

Objects.Submodule.root
----------------------

.. automodule:: git.objects.submodule.root
   :members:
   :undoc-members:
   :special-members:
   
Objects.Submodule.util
----------------------

.. automodule:: git.objects.submodule.util
   :members:
   :undoc-members:
   :special-members:
   
Objects.Util
-------------

.. automodule:: git.objects.util
   :members:
   :undoc-members:
   :special-members:

Index.Base
----------

.. automodule:: git.index.base
   :members:
   :undoc-members:
   :special-members:

Index.Functions
---------------

.. automodule:: git.index.fun
   :members:
   :undoc-members:
   :special-members:
   
Index.Types
-----------

.. automodule:: git.index.typ
   :members:
   :undoc-members:
   :special-members:
   
Index.Util
-------------

.. automodule:: git.index.util
   :members:
   :undoc-members:
   :special-members:
   
GitCmd
------

.. automodule:: git.cmd
   :members:
   :undoc-members:
   :special-members:

Config
------

.. automodule:: git.config
   :members:
   :undoc-members:
   :special-members:
   
Diff
----

.. automodule:: git.diff
   :members:
   :undoc-members:
   :special-members:

Exceptions
----------

.. automodule:: git.exc
   :members:
   :undoc-members:
   :special-members:

 
Refs.symbolic
-------------

.. automodule:: git.refs.symbolic
   :members:
   :undoc-members:
   :special-members:
   
Refs.reference
--------------

.. automodule:: git.refs.reference
   :members:
   :undoc-members:
   :special-members:

Refs.head
---------

.. automodule:: git.refs.head
   :members:
   :undoc-members:
   :special-members:
   
Refs.tag
------------

.. automodule:: git.refs.tag
   :members:
   :undoc-members:
   :special-members:
   
Refs.remote
------------

.. automodule:: git.refs.remote
   :members:
   :undoc-members:
   :special-members:
   
Refs.log
------------

.. automodule:: git.refs.log
   :members:
   :undoc-members:
   :special-members:
   
Remote
------

.. automodule:: git.remote
   :members:
   :undoc-members:
   :special-members:

Repo.Base
---------

.. automodule:: git.repo.base
   :members:
   :undoc-members:
   :special-members:
   
Repo.Functions
--------------

.. automodule:: git.repo.fun
   :members:
   :undoc-members:
   :special-members:

Util
----

.. automodule:: git.util
   :members:
   :undoc-members:
   :special-members:
